## 财务审计意见

接口：fina_audit

描述：获取上市公司定期财务审计意见数据

权限：用户需要至少500积分才可以调取，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码 |
| ann_date | str | N | 公告日期 |
| start_date | str | N | 公告开始日期 |
| end_date | str | N | 公告结束日期 |
| period | str | N | 报告期(每个季度最后一天的日期,比如20171231表示年报) |

输出参数

| 名称 | 类型 | 描述 |
| --- | --- | --- |
| ts_code | str | TS股票代码 |
| ann_date | str | 公告日期 |
| end_date | str | 报告期 |
| audit_result | str | 审计结果 |
| audit_fees | float | 审计总费用（元） |
| audit_agency | str | 会计事务所 |
| audit_sign | str | 签字会计师 |

接口使用

```python
pro = ts.pro_api()

df = pro.fina_audit(ts_code='600000.SH', start_date='20100101', end_date='20180808')
```

数据示例

```python
ts_code  ann_date  end_date        audit_result  audit_agency                audit_sign
0  600000.SH  20180428  20171231      标准无保留意见  普华永道中天会计师事务所      周章,张武
```